<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format"
	xmlns:java="java" exclude-result-prefixes="fo" xmlns:barcode="http://barcode4j.krysalis.org/ns">

	<xsl:output method="xml" version="1.0" omit-xml-declaration="no" indent="no" />

	<!-- ============================== -->
	<!-- Template: Single Barcode -->
	<!-- ============================== -->

	<xsl:template name="barcode">
		<xsl:param name="codeType" select="'code128'" />
		<xsl:param name="message" select="'NOT DEFINED'" />
		<xsl:param name="orientation" select="'0'" />
		<xsl:param name="fontSize" select="'10pt'" />
		<xsl:param name="height" select="'10mm'" />
		<xsl:param name="moduleWidth" select="'0.29mm'" />
		<xsl:param name="wideFactor" select="'3.0'" />
		<xsl:param name="placement" select="'bottom'" />
		<xsl:param name="fontName" select="'Arial'" />
		<fo:instream-foreign-object>
			<barcode:barcode xmlns:barcode="http://barcode4j.krysalis.org/ns" message="{$message}" orientation="{$orientation}">
				<xsl:choose>
					<xsl:when test="$codeType='code128'">
						<barcode:code128>
							<barcode:height>
								<xsl:value-of select="$height" />
							</barcode:height>
							<barcode:module-width>
								<xsl:value-of select="$moduleWidth" />
							</barcode:module-width>
							<barcode:quiet-zone enabled="false">0mw
							</barcode:quiet-zone>
							<barcode:human-readable>
								<barcode:font-size>
									<xsl:value-of select="$fontSize" />
								</barcode:font-size>
								<barcode:placement>
									<xsl:value-of select="$placement" />
								</barcode:placement>
							</barcode:human-readable>
						</barcode:code128>
					</xsl:when>
					<xsl:when test="$codeType='intl2of5'">
						<barcode:intl2of5>
							<barcode:checksum>ignore</barcode:checksum>
							<barcode:height>
								<xsl:value-of select="$height" />
							</barcode:height>
							<barcode:module-width>
								<xsl:value-of select="$moduleWidth" />
							</barcode:module-width>
							<barcode:quiet-zone enabled="false">0mw
							</barcode:quiet-zone>
							<barcode:wide-factor>
								<xsl:value-of select="$wideFactor" />
							</barcode:wide-factor>
							<barcode:human-readable>
								<barcode:font-name>
									<xsl:value-of select="$fontName" />
								</barcode:font-name>
								<barcode:display-checksum>false</barcode:display-checksum>
								<barcode:font-size>
									<xsl:value-of select="$fontSize" />
								</barcode:font-size>
								<barcode:placement>
									<xsl:value-of select="$placement" />
								</barcode:placement>
								<barcode:pattern>___ ___ ________ __</barcode:pattern>
							</barcode:human-readable>
						</barcode:intl2of5>
					</xsl:when>
					<xsl:when test="$codeType='codabar'">
						<barcode:codabar>
							<barcode:height>
								<xsl:value-of select="$height" />
							</barcode:height>
							<barcode:module-width>
								<xsl:value-of select="$moduleWidth" />
							</barcode:module-width>
							<barcode:quiet-zone enabled="false">0mw
							</barcode:quiet-zone>
							<barcode:human-readable>
								<barcode:font-size>
									<xsl:value-of select="$fontSize" />
								</barcode:font-size>
								<barcode:placement>
									<xsl:value-of select="$placement" />
								</barcode:placement>
							</barcode:human-readable>
						</barcode:codabar>
					</xsl:when>
					<xsl:when test="$codeType='pdf417'">
						<barcode:pdf417>
							<barcode:row-height>0.3mw</barcode:row-height>
							<barcode:module-width>0.352777mm</barcode:module-width>
							<barcode:quiet-zone enabled="true">2mw</barcode:quiet-zone>
							<barcode:vertical-quiet-zone enabled="true">2mw</barcode:vertical-quiet-zone>
							<barcode:columns>2</barcode:columns>
							<barcode:min-columns>2</barcode:min-columns>
							<barcode:max-columns>2</barcode:max-columns>
							<barcode:min-rows>5</barcode:min-rows>
							<barcode:max-rows>90</barcode:max-rows>
							<barcode:ec-level>2</barcode:ec-level>
							<barcode:width-to-height-ratio>3.0</barcode:width-to-height-ratio>
						</barcode:pdf417>
					</xsl:when>
					<xsl:when test="$codeType='datamatrix'">
						<barcode:datamatrix>
							<!-- 1 pixel at 72dpi -->
							<barcode:module-width>0.352777mm</barcode:module-width>
							<!-- <barcode:module-width>0.5mm</barcode:module-width> -->
							<barcode:quiet-zone enabled="true">1mw</barcode:quiet-zone>
							<barcode:shape>force-none</barcode:shape>
							<!-- <barcode:min-symbol-size>{dimension}</barcode:min-symbol-size> <barcode:max-symbol-size>{dimension}</barcode:max-symbol-size> -->
						</barcode:datamatrix>

					</xsl:when>

				</xsl:choose>
			</barcode:barcode>
		</fo:instream-foreign-object>
	</xsl:template>

</xsl:stylesheet>

