<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format"
	xmlns:java="java" exclude-result-prefixes="fo">

	<xsl:output method="xml" version="1.0" omit-xml-declaration="no"
		indent="no" />

	<xsl:include href="template://Barcode_Template.xsl" />

	<!-- ============================== -->
	<!-- Template: Single Sticker -->
	<!-- ============================== -->

	<xsl:template match="sticker">
		<xsl:choose>
			<xsl:when test="/report/demo = 'true'">
				<fo:block background-image="url('image://FOP_DEMO')"
					background-position="0,0" background-repeat="repeat"
					background-color="white" padding="0">
					<xsl:call-template name="main_table"></xsl:call-template>
				</fo:block>
			</xsl:when>
			<xsl:otherwise>
				<fo:block padding="0" font-size="3mm" wrap-option="wrap">
					<xsl:call-template name="main_table"></xsl:call-template>
				</fo:block>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="main_table">
		<!-- Sender box -->
		<fo:block font-size="3mm" border-width="0" padding="0"
			padding-bottom="1mm" wrap-option="wrap" overflow="hidden">
			<fo:block font-size="2.5mm" font-style="normal">
				<xsl:value-of select="/report/shipmentSenderNameLabel" />
			</fo:block>
			<xsl:choose>
				<xsl:when test="printSenderLogo = 'true'">
					<fo:block text-align="center" line-height="10mm">
						<fo:inline>
							<fo:external-graphic width="35mm" height="9mm"
								content-width="scale-to-fit" content-height="scale-to-fit"
								src="url('logo://expedit')" />
						</fo:inline>
					</fo:block>
				</xsl:when>
				<xsl:otherwise>
					<fo:block text-align="center" wrap-option="wrap"
						font-weight="bold" font-style="normal">
						<xsl:value-of select="sender/name" />
					</fo:block>
					<fo:block text-align="center" wrap-option="wrap">
						<xsl:value-of select="sender/address" />
					</fo:block>
					<fo:block text-align="center" font-size="2.5mm">
						<xsl:value-of select="sender/countryCode" />
						<xsl:text> </xsl:text>
						<xsl:value-of select="sender/postalCode" />
						<xsl:text>, </xsl:text>
						<xsl:value-of select="sender/city" />
					</fo:block>
					<xsl:choose>
						<xsl:when test="string-length(sender/phone) = 0">
							<fo:block>
								<xsl:text> </xsl:text>
							</fo:block>
						</xsl:when>
						<xsl:otherwise>
							<fo:block text-align="center" margin-left="0mm"
								wrap-option="wrap">
								<fo:inline padding-right="1mm">
									<fo:external-graphic height="2mm"
										content-width="scale-to-fit" src="url('image://FOP_ICON_PHONE')" />
								</fo:inline>
								<xsl:value-of select="sender/phone" />
							</fo:block>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:otherwise>
			</xsl:choose>
		</fo:block>

		<!-- Receiver box -->
		<fo:block font-size="3mm" border-style="dotted" border-width="0"
			border-top-width="thin" padding="0" padding-top="1mm" wrap-option="wrap"
			overflow="hidden">
			<fo:block font-size="2.5mm" font-style="normal">
				<xsl:value-of select="/report/shipmentReceiverNameLabel" />
			</fo:block>
			<fo:block text-align="center" wrap-option="wrap"
				font-weight="bold" font-style="normal">
				<xsl:value-of select="receiver/name" />
			</fo:block>
			<fo:block text-align="center" wrap-option="wrap">
				<xsl:value-of select="receiver/address" />
			</fo:block>
			<fo:block text-align="center" font-size="2.5mm">
				<xsl:value-of select="receiver/countryCode" />
				<xsl:text> </xsl:text>
				<xsl:value-of select="receiver/postalCode" />
				<xsl:text>, </xsl:text>
				<xsl:value-of select="receiver/city" />
			</fo:block>
			<fo:block text-align="center" margin-left="0mm">
				<fo:inline padding-right="1mm">
					<fo:external-graphic height="2mm"
						content-width="scale-to-fit" src="url('image://FOP_ICON_PHONE')" />
				</fo:inline>
				<xsl:value-of select="receiver/phone" />
			</fo:block>
		</fo:block>

		<!-- Barcode Postal code -->
		<fo:block text-align="right" margin-top="2mm">
			<xsl:call-template name="barcode">
				<xsl:with-param name="codeType" select="'postalCode'" />
				<xsl:with-param name="message" select="receiver/postalCode" />
			</xsl:call-template>
		</fo:block>

		<fo:block-container reference-orientation="90"
			inline-progression-dimension="63mm">

			<!-- Barcode multifunctional code -->
			<fo:block>
				<xsl:call-template name="barcode">
					<xsl:with-param name="codeType" select="'multifunctional'" />
					<xsl:with-param name="message" select="multifunctionalCode" />
				</xsl:call-template>
			</fo:block>

			<!-- Barcode Tracking code -->
			<fo:block>
				<xsl:call-template name="barcode">
					<xsl:with-param name="message" select="trackingCode" />
					<xsl:with-param name="codeType" select="'trackingCode'" />
				</xsl:call-template>
			</fo:block>
			<fo:block font-size="4.5mm">
				<xsl:value-of select="substring(trackingCode, 1, 6)" />
				<xsl:text> </xsl:text>
				<fo:inline font-weight="bold">
					<xsl:value-of select="substring(trackingCode, 7, 8)" />
				</fo:inline>
				<xsl:text> </xsl:text>
				<xsl:value-of select="substring(trackingCode, 15, 2)" />
			</fo:block>

			<!-- Reference box and services will be stored in additional table with 
				fixed height as, reference size may vary as well as services list -->
			<fo:block padding-top="4mm" wrap-option="wrap">
				<fo:table table-layout="fixed" width="50mm">
					<fo:table-column column-width="18mm" />
					<fo:table-column column-width="32mm" />
					<fo:table-body>
						<fo:table-row>
							<fo:table-cell>
								<fo:block font-size="3mm" font-weight="normal">
									<xsl:value-of select="date/label" />
									<xsl:text> </xsl:text>
								</fo:block>
							</fo:table-cell>
							<fo:table-cell>
								<fo:block font-size="3mm" font-weight="bold">
									<xsl:value-of select="date/value" />
								</fo:block>
							</fo:table-cell>
						</fo:table-row>
						<fo:table-row>
							<fo:table-cell>
								<fo:block font-size="3mm" font-weight="normal">
									<xsl:value-of select="weight/label" />
									<xsl:text> </xsl:text>
								</fo:block>
							</fo:table-cell>
							<fo:table-cell>
								<fo:block font-size="3mm" font-weight="bold">
									<xsl:value-of select="weight/value" />
								</fo:block>
							</fo:table-cell>
						</fo:table-row>
						<fo:table-row>
							<fo:table-cell>
								<fo:block font-size="3mm" font-weight="normal">
									<xsl:value-of select="referenceNr1/label" />
									<xsl:text> </xsl:text>
								</fo:block>
							</fo:table-cell>
							<fo:table-cell>
								<fo:block font-size="3mm" font-weight="bold">
									<xsl:value-of select="referenceNr1/value" />
								</fo:block>
							</fo:table-cell>
						</fo:table-row>
					</fo:table-body>
				</fo:table>
			</fo:block>

		</fo:block-container>

		<!-- Routing info -->
		<fo:block padding="2mm" padding-top="4mm">
			<fo:table table-layout="fixed" width="100%">
				<fo:table-body>
					<fo:table-row>
						<fo:table-cell>
							<fo:block font-size="4mm" font-weight="normal"
								text-align="left">
								<xsl:value-of select="routingSourceCenterAbbr" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell>
							<fo:block font-size="10mm" font-weight="bold"
								padding-left="3mm">
								<xsl:value-of select="routingDestCenterAbbr" />
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
					<fo:table-row>
						<fo:table-cell>
							<fo:block font-size="3mm" font-style="normal">
								<xsl:text> </xsl:text>
							</fo:block>
						</fo:table-cell>
						<fo:table-cell>
							<fo:block font-size="10mm" font-weight="bold"
								padding-left="3mm">
								<xsl:value-of select="routeNumber" />
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
				</fo:table-body>
			</fo:table>
		</fo:block>

		<!-- Footer -->
		<fo:table table-layout="fixed" width="100%">
			<fo:table-body>
				<fo:table-row>
					<fo:table-cell>
						<fo:block font-size="2mm" padding-left="2mm">
							<xsl:value-of select="/report/expeditInfo/name" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell>
						<fo:block font-size="3mm" text-align="right" font-weight="bold"
							padding-right="2mm">
							<xsl:value-of select="formattedPacketNumber" />
						</fo:block>
					</fo:table-cell>
				</fo:table-row>
			</fo:table-body>
		</fo:table>
	</xsl:template>

</xsl:stylesheet>

