<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:java="java"
	exclude-result-prefixes="fo"
>

	<xsl:output method="xml" version="1.0" omit-xml-declaration="no" indent="no" />

	<xsl:param name="body.font.family" expression="Arial, FreeSans" />
	<xsl:param name="title.font.family" expression="Arial, FreeSans" />
	<xsl:param name="monospace.font.family" expression="Arial, FreeSans" />
	<!-- <xsl:param name="body.font.master" select="'10.1'" /> -->
	<xsl:param name="symbol.font.family" expression="Arial, FreeSans" />
	<xsl:param name="body.fontset" expression="Arial, FreeSans" />

	<xsl:include href="template://Barcode_Template.xsl" />

	<!-- ============================== -->
	<!-- Template: Mini Report A4 Landscape -->
	<!-- ============================== -->

	<xsl:template match="report">
		<fo:root font-family="Arial, FreeSans">
			<fo:layout-master-set>
				<fo:simple-page-master master-name="whole_page" page-width="210mm" page-height="297mm" margin-top="5mm" margin-bottom="5mm" margin-left="10mm"
					margin-right="10mm"
				>
					<xsl:choose>
						<xsl:when test="/report/demo = 'true'">
							<fo:region-body margin-left="0" margin-right="0" margin-top="21mm" margin-bottom="21mm" background-image="url('image://FOP_DEMO')" background-position="0,0"
								background-repeat="repeat" background-color="white" />
						</xsl:when>
						<xsl:otherwise>
							<fo:region-body margin-left="0" margin-right="0" margin-top="21mm" margin-bottom="21mm" />
						</xsl:otherwise>
					</xsl:choose>
					<fo:region-before extent="20mm" />
					<fo:region-after extent="10mm" />
				</fo:simple-page-master>
			</fo:layout-master-set>

			<fo:page-sequence master-reference="whole_page">

				<fo:static-content flow-name="xsl-region-before">
					<!-- Header begin -->
					<fo:block>
						<fo:table width="100%">
							<fo:table-body>
								<fo:table-row>
									<fo:table-cell>
										<!-- Company info -->

										<!-- Barcode CargoNetID -->
										<fo:block padding="0.1mm" text-align="left">
											<xsl:call-template name="barcode">
												<xsl:with-param name="message" select="/report/shipperInfo/cargoNetID" />
												<xsl:with-param name="codeType" select="'rcid'" />
											</xsl:call-template>
										</fo:block>
										<fo:block font-size="3mm" padding-top="-1mm">
											<xsl:text>ID: </xsl:text>
											<xsl:value-of select="/report/shipperInfo/cargoNetID" />
										</fo:block>

										<fo:block font-size="4mm" font-weight="bold" font-style="italic" text-align="left" wrap-option="no-wrap">
											<xsl:value-of select="/report/shipperInfo/name" />
										</fo:block>
										<fo:block font-size="2.5mm" text-align="left" wrap-option="no-wrap">
											<xsl:value-of select="/report/shipperInfo/address" />
											<xsl:text>, </xsl:text>
											<xsl:value-of select="/report/shipperInfo/postalCode" />
											<xsl:text> </xsl:text>
											<xsl:value-of select="/report/shipperInfo/city" />
										</fo:block>
									</fo:table-cell>
									<fo:table-cell>
										<!-- Report header -->
										<fo:block font-size="4.5mm" font-weight="bold" text-align="center" wrap-option="no-wrap" margin-bottom="2mm">
											<xsl:value-of select="/report/lblMiniReportTitle" />
										</fo:block>
										<fo:block font-size="3.5mm" text-align="center">
											<fo:table width="100%">
												<fo:table-body>
													<fo:table-row>
														<fo:table-cell padding-right="2mm">
															<fo:block font-style="italic" text-align="right">
																<xsl:value-of select="/report/center/label" />
																<xsl:text>:</xsl:text>
															</fo:block>
														</fo:table-cell>
														<fo:table-cell>
															<fo:block font-weight="bold" text-align="left" wrap-option="no-wrap">
																<xsl:value-of select="/report/center/value" />
															</fo:block>
														</fo:table-cell>
													</fo:table-row>
													<fo:table-row>
														<fo:table-cell padding-right="2mm">
															<fo:block font-style="italic" text-align="right">
																<xsl:value-of select="/report/datum/label" />
																<xsl:text>: </xsl:text>
															</fo:block>
														</fo:table-cell>
														<fo:table-cell>
															<fo:block font-weight="bold" text-align="left" wrap-option="no-wrap">
																<xsl:value-of select="/report/datum/value" />
															</fo:block>
														</fo:table-cell>
													</fo:table-row>
												</fo:table-body>
											</fo:table>
										</fo:block>
									</fo:table-cell>
									<fo:table-cell>
										<!-- Licensee logo -->
										<xsl:choose>
											<xsl:when test="/report/printLicenseeLogoOnLabel = 'true'">
												<fo:block text-align="right">
													<fo:inline padding-right="0mm">
														<fo:external-graphic height="9mm" content-width="scale-to-fit" src='{concat("url(&apos;crimage://", /report/licenseeInfo/logoPathLabel, "&apos;)")}' />
													</fo:inline>
													<fo:block font-size="2.2mm" text-align="right" wrap-option="no-wrap">
														<xsl:value-of select="/report/licenseeInfo/address" />
														<xsl:text>, </xsl:text>
														<xsl:value-of select="/report/licenseeInfo/postalCode" />
														<xsl:text> </xsl:text>
														<xsl:value-of select="/report/licenseeInfo/city" />
													</fo:block>
													<fo:block font-size="2.2mm" text-align="right" font-style="italic" wrap-option="no-wrap">
														<xsl:value-of select="/report/licenseeInfo/httpAddress" />
													</fo:block>
												</fo:block>
											</xsl:when>
											<xsl:otherwise>
												<fo:block font-size="4mm" font-weight="bold" font-style="italic" text-align="right" wrap-option="no-wrap">
													<xsl:value-of select="/report/licenseeInfo/name" />
												</fo:block>
												<fo:block font-size="2.5mm" text-align="right" wrap-option="no-wrap">
													<xsl:value-of select="/report/licenseeInfo/address" />
													<xsl:text>, </xsl:text>
													<xsl:value-of select="/report/licenseeInfo/postalCode" />
													<xsl:text> </xsl:text>
													<xsl:value-of select="/report/licenseeInfo/city" />
												</fo:block>
												<fo:block font-size="2.5mm" text-align="right" font-style="italic" wrap-option="no-wrap">
													<xsl:value-of select="/report/licenseeInfo/httpAddress" />
												</fo:block>
											</xsl:otherwise>
										</xsl:choose>
									</fo:table-cell>
								</fo:table-row>
							</fo:table-body>
						</fo:table>
					</fo:block>
					<!-- Header end -->
				</fo:static-content>

				<fo:static-content flow-name="xsl-region-after">
					<!-- Footer begin -->
					<fo:block padding-top="1mm" border-style="solid" border-width="0" border-top-width="thin">
						<fo:table width="100%">
							<fo:table-body>
								<fo:table-row>
									<fo:table-cell>
										<fo:block font-size="2.5mm" text-align="left" wrap-option="no-wrap">
											<xsl:value-of select="/report/licenseeInfo/shortDescription" />
										</fo:block>
										<fo:block font-size="2mm" text-align="left" font-style="italic" wrap-option="no-wrap">
											<xsl:value-of select="/report/expeditInfo/name" />
											<!-- <xsl:text>, </xsl:text> <xsl:value-of select="/report/expeditInfo/httpAddress" /> -->
										</fo:block>
									</fo:table-cell>
									<fo:table-cell>
										<fo:block font-size="3mm" text-align="right" wrap-option="no-wrap">
											<xsl:value-of select="/report/lblPage" />
											<xsl:text> </xsl:text>
											<fo:page-number />
											<xsl:text> </xsl:text>
											<xsl:value-of select="/report/lblPageOf" />
											<xsl:text> </xsl:text>
											<fo:page-number-citation ref-id="endOfDocument" />
										</fo:block>
									</fo:table-cell>
								</fo:table-row>
							</fo:table-body>
						</fo:table>
					</fo:block>
					<!-- Footer end -->
				</fo:static-content>

				<fo:flow flow-name="xsl-region-body">
					<fo:block>
						<fo:table width="100%" table-omit-header-at-break="false">
							<fo:table-header>
								<fo:table-row margin-bottom="10mm">
									<fo:table-cell border-style="solid" border-width="0" border-top-width="thin" border-bottom-width="thin" width="5mm">
										<fo:block font-size="2.5mm" font-weight="bold" text-align="left" padding-top="1mm" padding-bottom="0.5mm">
											<xsl:value-of select="/report/lblOrdinalNr" />
										</fo:block>
									</fo:table-cell>
									<fo:table-cell border-style="solid" border-width="0" border-top-width="thin" border-bottom-width="thin">
										<fo:block font-size="2.5mm" font-weight="bold" text-align="left" padding-top="1mm" padding-bottom="0.5mm">
											<xsl:value-of select="/report/lblReceiver" />
										</fo:block>
									</fo:table-cell>
									<fo:table-cell border-style="solid" border-width="0" border-top-width="thin" border-bottom-width="thin">
										<fo:block font-size="2.5mm" font-weight="bold" text-align="left" padding-top="1mm" padding-bottom="0.5mm">
											<xsl:value-of select="/report/lblContactPerson" />
										</fo:block>
									</fo:table-cell>
									<fo:table-cell border-style="solid" border-width="0" border-top-width="thin" border-bottom-width="thin">
										<fo:block font-size="2.5mm" font-weight="bold" text-align="left" padding-top="1mm" padding-bottom="0.5mm">
											<xsl:value-of select="/report/lblPhone" />
										</fo:block>
									</fo:table-cell>
									<fo:table-cell border-style="solid" border-width="0" border-top-width="thin" border-bottom-width="thin">
										<fo:block font-size="2.5mm" font-weight="bold" text-align="left" padding-top="1mm" padding-bottom="0.5mm">
											<xsl:value-of select="/report/lblAddress" />
										</fo:block>
									</fo:table-cell>
									<fo:table-cell border-style="solid" border-width="0" border-top-width="thin" border-bottom-width="thin">
										<fo:block font-size="2.5mm" font-weight="bold" text-align="left" padding-top="1mm" padding-bottom="0.5mm">
											<xsl:value-of select="/report/lblPostalCodeAndCity" />
										</fo:block>
									</fo:table-cell>
									<fo:table-cell border-style="solid" border-width="0" border-top-width="thin" border-bottom-width="thin" width="14mm">
										<fo:block font-size="2.5mm" font-weight="bold" text-align="left" padding-top="1mm" padding-bottom="0.5mm">
											<xsl:value-of select="/report/lblServices" />
										</fo:block>
									</fo:table-cell>
									<fo:table-cell border-style="solid" border-width="0" border-top-width="thin" border-bottom-width="thin" width="11.5mm">
										<fo:block font-size="2.5mm" font-weight="bold" text-align="left" padding-top="1mm" padding-bottom="0.5mm">
											<xsl:value-of select="/report/lblCashOnDeliveryValue" />
										</fo:block>
									</fo:table-cell>
									<fo:table-cell border-style="solid" border-width="0" border-top-width="thin" border-bottom-width="thin" width="12.5mm">
										<fo:block font-size="2.5mm" font-weight="bold" text-align="left" padding-top="1mm" padding-bottom="0.5mm">
											<xsl:value-of select="/report/lblInsuranceValue" />
										</fo:block>
									</fo:table-cell>
									<!-- Delivery remark is excluded for Slovakia -->
									<!-- <fo:table-cell border-style="solid" border-width="0" border-top-width="thin" border-bottom-width="thin" width="30mm"> <fo:block font-size="2.5mm" font-weight="bold" text-align="left" 
										padding-top="1mm" padding-bottom="1mm"> <xsl:value-of select="/report/lblDeliveryRemark" /> </fo:block> </fo:table-cell> -->
									<fo:table-cell border-style="solid" border-width="0" border-top-width="thin" border-bottom-width="thin" width="15mm">
										<fo:block font-size="2.5mm" font-weight="bold" text-align="left" padding-top="1mm" padding-bottom="0.5mm">
											<xsl:value-of select="/report/lblReferenceNumbers" />
										</fo:block>
									</fo:table-cell>
									<fo:table-cell border-style="solid" border-width="0" border-top-width="thin" border-bottom-width="thin" width="13mm">
										<fo:block font-size="2.5mm" font-weight="bold" text-align="left" padding-top="1mm" padding-left="2mm" padding-bottom="0.5mm">
											<xsl:value-of select="/report/weight/label" />
										</fo:block>
									</fo:table-cell>
								</fo:table-row>
							</fo:table-header>
							<fo:table-body>
								<!-- Main content begin -->
								<xsl:for-each select="shipmentsInfo/shipmentInfo">
									<xsl:apply-templates select="." />
								</xsl:for-each>
								<!-- Main content end -->
							</fo:table-body>
						</fo:table>
					</fo:block>
					<fo:block id="endOfDocument">
						<fo:block font-size="2.5mm" font-weight="normal" text-decoration="none" text-align="right" wrap-option="wrap" margin-top="7mm" margin-bottom="0.5mm">
							<xsl:value-of select="/report/numberOfShipments/label" />
							<xsl:text>: </xsl:text>
							<xsl:value-of select="/report/numberOfShipments/value" />
						</fo:block>
						<fo:block font-size="2.5mm" font-weight="normal" text-decoration="none" text-align="right" wrap-option="wrap" margin-top="1mm" margin-bottom="0.5mm">
							<xsl:value-of select="/report/numberOfParcels/label" />
							<xsl:text>: </xsl:text>
							<xsl:value-of select="/report/numberOfParcels/value" />
						</fo:block>
					</fo:block>
				</fo:flow>

			</fo:page-sequence>
		</fo:root>
	</xsl:template>

	<xsl:template match="shipmentInfo">
		<fo:table-row>
			<fo:table-cell number-rows-spanned="2" border-bottom-style="solid" border-bottom-width="thin" display-align="center">
				<fo:block font-size="2mm" font-weight="bold" padding-top="0.5mm" padding-bottom="0">
					<xsl:value-of select="@ordinalNr" />
					<xsl:text>.</xsl:text>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell keep-together.within-column="always" wrap-option="wrap">
				<fo:block font-size="2mm" text-align="left" padding-top="0.5mm" padding-bottom="0">
					<xsl:value-of select="receiver/name" />
				</fo:block>
			</fo:table-cell>
			<fo:table-cell keep-together.within-column="always" wrap-option="wrap">
				<fo:block font-size="2mm" text-align="left" padding-top="0.5mm" padding-bottom="0">
					<xsl:value-of select="contactPersonName" />
				</fo:block>
			</fo:table-cell>
			<fo:table-cell keep-together.within-column="always" wrap-option="wrap">
				<fo:block font-size="2mm" text-align="left" padding-top="0.5mm" padding-bottom="0">
					<xsl:value-of select="receiver/phone" />
				</fo:block>
			</fo:table-cell>
			<fo:table-cell keep-together.within-column="always" wrap-option="wrap">
				<fo:block font-size="2mm" text-align="left" padding-top="0.5mm" padding-bottom="0">
					<xsl:value-of select="receiver/address" />
				</fo:block>
			</fo:table-cell>
			<fo:table-cell keep-together.within-column="always" wrap-option="wrap">
				<fo:block font-size="2mm" text-align="left" padding-top="0.5mm" padding-bottom="0">
					<xsl:value-of select="receiver/postalCode" />
					<xsl:text> </xsl:text>
					<xsl:value-of select="receiver/city" />
					<xsl:choose>
						<xsl:when test="receiver/countryCode = 'SK'">
						</xsl:when>
						<xsl:otherwise>
							<xsl:text>, </xsl:text>
							<xsl:value-of select="receiver/countryName" />
						</xsl:otherwise>
					</xsl:choose>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell keep-together.within-column="always" wrap-option="wrap">
				<fo:block font-size="2mm" text-align="left" padding-top="0.5mm" padding-bottom="0">
					<xsl:value-of select="servicesDescriptor" />
				</fo:block>
			</fo:table-cell>
			<fo:table-cell>
				<fo:block font-size="2mm" text-align="left" padding-top="0.5mm" padding-bottom="0">
					<xsl:value-of select="cashOnDeliveryValue" />
				</fo:block>
			</fo:table-cell>
			<fo:table-cell>
				<fo:block font-size="2mm" text-align="left" padding-top="0.5mm" padding-bottom="0">
					<xsl:value-of select="insuranceValue" />
				</fo:block>
			</fo:table-cell>
			<!-- Delivery remark is excluded for Slovakia -->
			<!-- <fo:table-cell border-bottom-style="solid" border-bottom-width="thin"> <fo:block font-size="2mm" text-align="left" padding-top="1mm" padding-bottom="1mm"> <xsl:value-of select="remark" 
				/> </fo:block> </fo:table-cell> -->
			<fo:table-cell>
				<fo:block font-size="2mm" text-align="left" padding-top="0.5mm" padding-bottom="0">
					<xsl:call-template name="forcedWrapText">
						<xsl:with-param name="data" select="referenceNr1" />
					</xsl:call-template>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell>
				<fo:block font-size="2mm" text-align="left" padding-top="0.5mm" padding-bottom="0">
					<xsl:value-of select="weight" />
				</fo:block>
			</fo:table-cell>
		</fo:table-row>
		<fo:table-row keep-with-previous.within-page="always">
			<fo:table-cell number-columns-spanned="1" border-bottom-style="solid" border-bottom-width="thin">
				<fo:block font-size="2mm" text-align="left" padding-top="0.5mm" padding-bottom="0.5mm">
					<xsl:value-of select="/report/numberOfParcels/label" />
					<xsl:text>: </xsl:text>
					<xsl:value-of select="numberOfParcels" />
				</fo:block>
			</fo:table-cell>
			<fo:table-cell number-columns-spanned="9" border-bottom-style="solid" border-bottom-width="thin">
				<fo:block font-size="2mm" text-align="left" padding-top="0.5mm" padding-bottom="0.5mm">
					<xsl:value-of select="/report/lblParcelsNumbers" />
					<xsl:text>. </xsl:text>
					<xsl:for-each select="packetsInfo/packetsRow/packetCode">
						<xsl:value-of select="." />
						<xsl:text> </xsl:text>
					</xsl:for-each>
				</fo:block>
			</fo:table-cell>
		</fo:table-row>
	</xsl:template>

	<xsl:template name="forcedWrapText">
		<xsl:param name="data" />
		<xsl:param name="counter" select="1" />
		<xsl:choose>
			<xsl:when test="$counter &lt;= string-length($data)">
				<xsl:value-of select='concat(substring($data,$counter,1),"&#8203;")' />
				<xsl:call-template name="forcedWrapText">
					<xsl:with-param name="data" select="$data" />
					<xsl:with-param name="counter" select="$counter+1" />
				</xsl:call-template>
			</xsl:when>
		</xsl:choose>
	</xsl:template>

</xsl:stylesheet>

